diff --git a/meshmode/mesh/__init__.py b/meshmode/mesh/__init__.py
index 4cc8d5cb8ff96ee9e2a6453ee0ed7f4670f02a91..e1a9566d047948a2e99a577ecae6013f3c6210c2 100644
--- a/meshmode/mesh/__init__.py
+++ b/meshmode/mesh/__init__.py
@@ -392,8 +392,9 @@ class FacialAdjacencyGroup(Record):
     .. image:: images/facial-adjacency-group.png
 
     Represents (for example) *one* of the (colored) interfaces between
-    :class:`MeshElementGroup` instances. (Note that element groups are not
-    necessarily contiguous as the imagee may suggest.)
+    :class:`MeshElementGroup` instances, or an interface between
+    :class:`MeshElementGroup` and a boundary. (Note that element groups are not
+    necessarily contiguous like the figure may suggest.)
 
     .. attribute:: igroup
 
@@ -501,10 +502,13 @@ class Mesh(Record):
                 {       # connectivity for group 3
                     1: FacialAdjacencyGroup(...)  # towards group 1, green
                     2: FacialAdjacencyGroup(...)  # towards group 2, pink
-                    None: FacialAdjacencyGroup(...)  # towards the boundary
+                    None: FacialAdjacencyGroup(...)  # towards the boundary, orange
                 }
             ]
 
+        (Note that element groups are not necessarily contiguous like the figure
+        may suggest.)
+
     .. attribute:: boundary_tags
 
         A tuple of boundary tag identifiers. :class:`BTAG_ALL` and